pmchen: main function

Description Usage Arguments Value Examples

View source: R/pmchen.r

Description

This is the function allows you to calculate p value

Usage

1
2
3
4
5
6
pmchen(
  x,
  y,
  method = c("weighted_z", "mle_hetero", "mle_homo", "modified_t", "zcorr"),
  alternative = "two.sided"
)

Arguments

x

a (non-empty) numeric vector of data values(tumor sample)

y

a (non-empty) numeric vector of data values(matched normal sample)

method

a character string indicating which method is to be computed. One of the "weighted"(default),"mle_hetero","mle_hoto","zcorr",or "modified_t".

alternative

a character string specifying the alternative hypothesis, must be one of "two.sided" (default), "greater" or "less". You can specify just the initial letter.

Value

statistics p-value of several methods for handing partially matched sample (tumor and matched normal sample) test by using meta-analysis framework.

Examples

 1
 2
 3
 4
 5
 6
 7
 8
 9
10
11
12
13
set.seed(123)
n=20
x=rnorm(n) 
y=rnorm(n)
x[1:5]=NA
y[7:10]=NA
pmchen(x,y,method="weighted_z",alternative="two.sided")
pmchen(x,y,method="mle_hetero",alternative="two.sided")
pmchen(x,y,method="mle_homo",alternative="two.sided")
pmchen(x,y,method="zcorr",alternative="two.sided")
pmchen(x,y,method="modified_t",alternative="two.sided")
pmchen(x,y)
pmchen(x,y,method="modified_t",alternative="great")

JennyChen9827/P-Values-Pooling-Approach-with-R documentation built on Dec. 18, 2021, 1:28 a.m.