Description Usage Arguments Value Examples
This is the function allows you to calculate p value
1 2 3 4 5 6 |
x |
a (non-empty) numeric vector of data values(tumor sample) |
y |
a (non-empty) numeric vector of data values(matched normal sample) |
method |
a character string indicating which method is to be computed. One of the "weighted"(default),"mle_hetero","mle_hoto","zcorr",or "modified_t". |
alternative |
a character string specifying the alternative hypothesis, must be one of "two.sided" (default), "greater" or "less". You can specify just the initial letter. |
statistics p-value of several methods for handing partially matched sample (tumor and matched normal sample) test by using meta-analysis framework.
1 2 3 4 5 6 7 8 9 10 11 12 13 | set.seed(123)
n=20
x=rnorm(n)
y=rnorm(n)
x[1:5]=NA
y[7:10]=NA
pmchen(x,y,method="weighted_z",alternative="two.sided")
pmchen(x,y,method="mle_hetero",alternative="two.sided")
pmchen(x,y,method="mle_homo",alternative="two.sided")
pmchen(x,y,method="zcorr",alternative="two.sided")
pmchen(x,y,method="modified_t",alternative="two.sided")
pmchen(x,y)
pmchen(x,y,method="modified_t",alternative="great")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.